@@ -10,9 +10,20 @@ from astropy.utils.data import get_pkg_data_filename
 from astropy.modeling import models
 from astropy.tests.helper import quantity_allclose
 from ..manipulation import noise_region_uncertainty
+from ..wcs.adapters import fitswcs_adapter
 
 from ..spectra import Spectrum1D, SpectralRegion
 
+def test_empty_spectrum():
+    spec = Spectrum1D(spectral_axis=[]*u.um,
+                      flux=[]*u.Jy)
+
+    assert isinstance(spec.spectral_axis, u.Quantity)
+    assert spec.spectral_axis.size == 0
+
+    assert isinstance(spec.flux, u.Quantity)
+    assert spec.flux.size == 0
+
 
 def test_create_from_arrays():
     spec = Spectrum1D(spectral_axis=np.arange(50) * u.AA,
@@ -157,6 +168,8 @@ def test_wcs_transformations():
     assert isinstance(pix_axis, np.ndarray)
     assert isinstance(disp_axis, u.Quantity)
 
+    assert np.allclose(spec.wcs.world_to_pixel([7000*u.AA, 700*u.nm]), [461.2, 461.2])
+
 def test_create_explicit_fitswcs():
     my_wcs = fitswcs.WCS(header={'CDELT1': 1, 'CRVAL1': 6562.8, 'CUNIT1': 'Angstrom',
                                  'CTYPE1': 'WAVE', 'RESTFRQ': 1400000000, 'CRPIX1': 25})
@@ -274,36 +287,3 @@ def test_str():
     spec_single_flux = Spectrum1D(1 * u.Jy)
     result = str(spec_single_flux)
     assert result == 'Spectrum1D (length=1)\nflux:   {}'.format(spec_single_flux.flux)
-
-
-def test_noise_estimate_uncertainty():
-
-    np.random.seed(42)
-
-    # Create values for spectrum.
-    frequencies = np.linspace(1, 100, 10000) * u.um
-    g = models.Gaussian1D(amplitude=1*u.Jy, mean=10*u.um, stddev=1*u.um)
-    noise = np.random.normal(0., 0.01, frequencies.shape) * u.Jy
-    flux = g(frequencies) + noise
-
-    # Create the spectrum, spectral region and assign uncertainties
-    spectrum = Spectrum1D(spectral_axis=frequencies, flux=flux)
-    spectral_region = SpectralRegion(50*u.um, 80*u.um)
-    spectrum_with_uncertainty = noise_region_uncertainty(spectrum, spectral_region)
-
-    # Compute the expected.
-    indices = np.nonzero((frequencies >= 50*u.um) & (frequencies <= 80*u.um))
-    expected_uncertainty = np.std(flux[indices])*np.ones(len(frequencies))
-
-    assert quantity_allclose(spectrum_with_uncertainty.uncertainty.array,
-                             expected_uncertainty.value)
-
-    # Same idea, but now with variance.  Create the spectrum, spectral region and assign uncertainties
-    spectrum_with_uncertainty = noise_region_uncertainty(spectrum, spectral_region, np.var)
-
-    # Compute the expected.
-    indices = np.nonzero((frequencies >= 50*u.um) & (frequencies <= 80*u.um))
-    expected_uncertainty = np.var(flux[indices])*np.ones(len(frequencies))
-
-    assert quantity_allclose(spectrum_with_uncertainty.uncertainty.array,
-                             expected_uncertainty.value)
